@@ -1,16 +1,14 @@
 use strictures 1;
 package Mojito::Template;
 BEGIN {
-  $Mojito::Template::VERSION = '0.07';
+  $Mojito::Template::VERSION = '0.08';
 }
 use Moo;
-use Mojito::Model::Config;
-use Cwd qw/ abs_path /;
-use Dir::Self;
+use Mojito::Types;
 use Data::Dumper::Concise;
 
-my $config = Mojito::Model::Config->new->config;
-my $static_url = $config->{static_url};
+with('Mojito::Template::Role::Javascript');
+with('Mojito::Template::Role::CSS');
 
 has 'template' => (
     is      => 'rw',
@@ -26,27 +24,24 @@ has 'home_page' => (
     builder => '_build_home_page',
 );
 
-my $javascripts = [
-    'jquery/jquery-1.5.min.js',     'javascript/render_page.js',
-    'syntax_highlight/prettify.js', 'jquery/autoresize.jquery.min.js',
-];
-my @javascripts = map { "<script src=${static_url}$_></script>" } @{$javascripts};
-
-my $css = [ 'syntax_highlight/prettify.css', 'css/mojito.css', ];
-my @css =
-  map { "<link href=${static_url}$_ type=text/css rel=stylesheet />" } @{$css};
-
-my $js_css = join "\n", @javascripts, @css;
+has js_css_html => (
+    is => 'ro',
+    isa => Mojito::Types::NoRef,
+    default => sub { my $self = shift; join "\n", @{$self->javascript_html}, @{$self->css_html} }
+);
 
 sub _build_template {
     my $self = shift;
 
     my $base_url  = $self->base_url;
+    my $mojito_version = $self->config->{VERSION};
+    my $js_css = $self->js_css_html;
     my $edit_page = <<"END_HTML";
 <!doctype html>
-<html> 
+<html>
 <head>
   <meta charset=utf-8>
+  <meta http-equiv="powered by" content="Mojito $mojito_version" />
   <title>Mojito page</title>
 $js_css
 <script></script>
@@ -62,8 +57,8 @@ $js_css
 <form id="editForm" action="" accept-charset="UTF-8" method="post">
     <input id="mongo_id" name="mongo_id" type="hidden" form="editForm" value="" />
     <textarea id="content"  name="content" rows=32 /></textarea><br />
-    <input id="submit_save" name="submit" type="submit" value="Save" /> 
-    <input id="submit_view" name="submit" type="submit" value="Done" /> 
+    <input id="submit_save" name="submit" type="submit" value="Save" />
+    <input id="submit_view" name="submit" type="submit" value="Done" />
 </form>
 </section>
 <section id="view_area" class="view_area_edit_mode"></section>
@@ -84,11 +79,14 @@ sub _build_home_page {
     my $self = shift;
 
     my $base_url  = $self->base_url;
+    my $mojito_version = $self->config->{VERSION};
+    my $js_css = $self->js_css_html;
     my $home_page = <<"END_HTML";
 <!doctype html>
-<html> 
+<html>
 <head>
   <meta charset=utf-8>
+  <meta http-equiv="powered by" content="Mojito $mojito_version" />
   <title>Mojito page</title>
 $js_css
 <script></script>
